@@ -8,7 +8,7 @@ import time, datetime
 import sys
 import shutil
 from cvdastwrapper import runconfig
-import apispecs
+from cvdastwrapper import apispecs
 
 resultrootn = runconfig.dresultdir + "/" + runconfig.dperadir + "/"
 ainfofname  = runconfig.dainfofname
