@@ -19,6 +19,7 @@ from cvdastwrapper import runconfig
 from cvdastwrapper.runperapi import perapicall
 from cvdastwrapper.runperattack import perattackcall
 from cvdastwrapper.runconfig import fuzzattacklist
+from cvdastwrapper.htmlreportgenerator import iterateallspecs, generate_html_report
 
 from datetime import datetime
 
@@ -66,7 +67,8 @@ def main():
         htmlfname = htmlfname+"-"+tstamp+".html"
     if addcsvtstamp:
         csvfname  = csvfname+"-"+tstamp+".csv"
-        
+    if not regen:    
+        runconfig.dhostname = input("Enter the Destination Host To Test : ")    
 
     reportutil.init()
 
@@ -98,6 +100,7 @@ def main():
     f.close()
 
     result_report = iterateallspecs(runconfig.apispeclist, runconfig.fuzzattacklist)
+    #print("-----+++",result_report)
     generate_html_report(result_report, "report_summary_"+str(time.time())+".html")
     
 if __name__ == "__main__":
